@@ -34,7 +34,7 @@ function install() {
   }
 
   // now try to download it
-  return downloadZipFile(url).then(() => {
+  return downloadZipFileWithRetries(url).then(() => {
     verifyZipChecksum();
     return extractZipFile().then(() => {
       // todo: how to just +x? does it matter?
@@ -75,6 +75,24 @@ function install() {
     }
   }
 
+  function downloadZipFileWithRetries(url) {
+    /** @param remaining {number} */
+    function download(remaining) {
+      return downloadZipFile(url)
+        .catch(err => {
+          if (remaining === 0) {
+            return Promise.reject(err);
+          } else {
+            console.error("Error downloading dprint zip file.", err);
+            console.error("Retrying download (remaining: " + remaining + ")");
+            return download(remaining - 1);
+          }
+        });
+    }
+
+    return download(3);
+  }
+
   function downloadZipFile(url) {
     return new Promise((resolve, reject) => {
       https.get(url, function(response) {
